Struct forky_play::physics::EulerPhysicsPlugin
source · pub struct EulerPhysicsPlugin;Trait Implementations
sourceimpl Plugin for EulerPhysicsPlugin
impl Plugin for EulerPhysicsPlugin
fn setup(&self, _app: &mut App)
fn setup(&self, _app: &mut App)
Runs after all plugins are built, but before the app runner is called.
This can be useful if you have some resource that other plugins need during their build step,
but after build you want to remove it and send it to another thread.