Struct forky_play::plugins::CustomDefaultPlugin
source · pub struct CustomDefaultPlugin;Trait Implementations
sourceimpl Plugin for CustomDefaultPlugin
impl Plugin for CustomDefaultPlugin
fn setup(&self, _app: &mut App)
fn setup(&self, _app: &mut App)
Runs after all plugins are built, but before the app runner is called.
This can be useful if you have some resource that other plugins need during their build step,
but after build you want to remove it and send it to another thread.