Struct forky_play::plugins::ForkyFullPlugin
source · pub struct ForkyFullPlugin {
pub debug_plugin: ForkyDebugPlugin,
pub physics_plugin: PhysicsPlugin,
pub tool_plugin: ToolPlugin,
}Fields
debug_plugin: ForkyDebugPluginphysics_plugin: PhysicsPlugintool_plugin: ToolPluginTrait Implementations
sourceimpl Clone for ForkyFullPlugin
impl Clone for ForkyFullPlugin
sourcefn clone(&self) -> ForkyFullPlugin
fn clone(&self) -> ForkyFullPlugin
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Default for ForkyFullPlugin
impl Default for ForkyFullPlugin
sourcefn default() -> ForkyFullPlugin
fn default() -> ForkyFullPlugin
Returns the “default value” for a type. Read more
sourceimpl Plugin for ForkyFullPlugin
impl Plugin for ForkyFullPlugin
fn setup(&self, _app: &mut App)
fn setup(&self, _app: &mut App)
Runs after all plugins are built, but before the app runner is called.
This can be useful if you have some resource that other plugins need during their build step,
but after build you want to remove it and send it to another thread.